Class SlackApiLambdaHandler

java.lang.Object
com.slack.api.bolt.aws_lambda.SlackApiLambdaHandler
All Implemented Interfaces:
com.amazonaws.services.lambda.runtime.RequestHandler<ApiGatewayRequest,ApiGatewayResponse>

public abstract class SlackApiLambdaHandler extends Object implements com.amazonaws.services.lambda.runtime.RequestHandler<ApiGatewayRequest,ApiGatewayResponse>
The AWS Lambda handler base class. A subclass that inherits this abstract class works as a Lambda handler.
See Also:
  • Constructor Details

    • SlackApiLambdaHandler

      public SlackApiLambdaHandler(App app)
  • Method Details

    • isWarmupRequest

      protected abstract boolean isWarmupRequest(ApiGatewayRequest awsReq)
      Returns true if the given incoming request is an internal warmup request. You can use your own logic for distinguishing requests from Slack from your own internal warmup trigger.
    • handleRequest

      public ApiGatewayResponse handleRequest(ApiGatewayRequest input, com.amazonaws.services.lambda.runtime.Context context)
      Specified by:
      handleRequest in interface com.amazonaws.services.lambda.runtime.RequestHandler<ApiGatewayRequest,ApiGatewayResponse>
    • app

      protected App app()
      Returns the underlying App instance in this handler.
    • toSlackRequest

      protected Request<?> toSlackRequest(ApiGatewayRequest awsReq)
    • toApiGatewayResponse

      protected ApiGatewayResponse toApiGatewayResponse(Response slackResp)