Package com.slack.api.bolt.aws_lambda
Class SlackApiLambdaHandler
java.lang.Object
com.slack.api.bolt.aws_lambda.SlackApiLambdaHandler
- All Implemented Interfaces:
com.amazonaws.services.lambda.runtime.RequestHandler<ApiGatewayRequest,ApiGatewayResponse>
public abstract class SlackApiLambdaHandler
extends Object
implements com.amazonaws.services.lambda.runtime.RequestHandler<ApiGatewayRequest,ApiGatewayResponse>
The AWS Lambda handler base class. A subclass that inherits this abstract class works as a Lambda handler.
- See Also:
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionprotected Appapp()Returns the underlyingAppinstance in this handler.handleRequest(ApiGatewayRequest input, com.amazonaws.services.lambda.runtime.Context context) protected abstract booleanisWarmupRequest(ApiGatewayRequest awsReq) Returns true if the given incoming request is an internal warmup request.protected ApiGatewayResponsetoApiGatewayResponse(Response slackResp) protected Request<?>toSlackRequest(ApiGatewayRequest awsReq)
-
Constructor Details
-
SlackApiLambdaHandler
-
-
Method Details
-
isWarmupRequest
Returns true if the given incoming request is an internal warmup request. You can use your own logic for distinguishing requests from Slack from your own internal warmup trigger. -
handleRequest
public ApiGatewayResponse handleRequest(ApiGatewayRequest input, com.amazonaws.services.lambda.runtime.Context context) - Specified by:
handleRequestin interfacecom.amazonaws.services.lambda.runtime.RequestHandler<ApiGatewayRequest,ApiGatewayResponse>
-
app
Returns the underlyingAppinstance in this handler. -
toSlackRequest
-
toApiGatewayResponse
-