Class SlackApiLambdaHandler

    • Constructor Detail

      • SlackApiLambdaHandler

        public SlackApiLambdaHandler​(App app)
    • Method Detail

      • isWarmupRequest

        protected abstract boolean isWarmupRequest​(ApiGatewayRequest awsReq)
        Returns true if the given incoming request is an internal warmup request. You can use your own logic for distinguishing requests from Slack from your own internal warmup trigger.
      • app

        protected App app()
        Returns the underlying App instance in this handler.